@@ -45,7 +45,7 @@ def _indicator(value: float):
 def impact_value(impact_assessment: dict, term_id: str):
     impact = find_term_match(impact_assessment.get('impacts', []), term_id)
     value = impact.get('value')
-    value = safe_parse_float(value, None)
+    value = safe_parse_float(value, default=None)
     debugValues(impact, model=MODEL, term=TERM_ID, node=term_id, value=value, coefficient=1)
     return value
 
