@@ -1,22 +1,8 @@
-"""
-Product Economic Value Share
-
-This model quantifies the relative economic value share of each marketable Product in a Cycle.
-Marketable Products are all Products identified with the lookup "generateImpactAssessment = TRUE".
-
-It works in the following order:
-1. For every product with no `value`, the `economicValueShare` is set to `0`.
-2. If revenue data are provided for all marketable products,
-the `economicValueShare` is directly calculated as the share of revenue of each Product;
-3. Based on a lookup table containing typical global average economic value shares
-drawn from [Poore & Nemecek (2018)](https://science.sciencemag.org/content/360/6392/987), if all products have a
-corresponding value, the `economicValueShare` will be proportionally distributed among the products.
-"""
 from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.tools import list_sum
 
 from hestia_earth.models.log import logRequirements, logShouldRun, log_as_table
-from hestia_earth.models.utils.blank_node import get_lookup_value
+from hestia_earth.models.utils.term import get_lookup_value
 from hestia_earth.models.utils.cycle import unique_currencies
 from .utils import lookup_share
 from .. import MODEL
@@ -45,8 +31,10 @@ RETURNS = {
 LOOKUPS = {
     "@doc": "Depending on the primary product [termType](https://hestia.earth/schema/Product#term)",
     "crop": "global_economic_value_share",
+    "processedFood": "global_economic_value_share",
     "excreta": "global_economic_value_share",
-    "animalProduct": "global_economic_value_share"
+    "animalProduct": "global_economic_value_share",
+    "waste": "global_economic_value_share"
 }
 MODEL_KEY = 'economicValueShare'
 MAX_VALUE = 100.5
