@@ -4,12 +4,13 @@ from hestia_earth.schema import EmissionMethodTier
 
 from hestia_earth.models.log import logShouldRun, logRequirements, debugValues
 from hestia_earth.models.utils.emission import _new_emission
+from hestia_earth.models.utils.background_emissions import get_background_inputs, no_gap_filled_background_emissions
 from hestia_earth.models.utils.blank_node import group_by_keys
 from hestia_earth.models.utils.completeness import _is_term_type_complete
 from hestia_earth.models.utils.term import get_electricity_grid_mix_terms
 from hestia_earth.models.data.ecoinventV3 import ecoinventV3_emissions
 from .utils import get_input_coefficient
-from ..ecoinventV3.utils import get_background_inputs, get_input_mappings
+from ..ecoinventV3.utils import get_input_mappings
 
 REQUIREMENTS = {
     "Cycle": {
@@ -88,6 +89,7 @@ def _add_emission(cycle: dict, input: dict):
         emissions = ecoinventV3_emissions(ecoinventName)
         for emission_term_id, value in emissions:
             # log run on each emission so we know it did run
+            logShouldRun(cycle, MODEL, input_term_id, True, methodTier=TIER, emission_id=emission_term_id)
             debugValues(cycle, model=MODEL, term=emission_term_id,
                         value=value,
                         coefficient=coefficient,
@@ -101,6 +103,7 @@ def _add_emission(cycle: dict, input: dict):
 
 def _run_input(cycle: dict):
     electricity_complete = _is_term_type_complete(cycle, 'electricityFuel')
+    no_gap_filled_background_emissions_func = no_gap_filled_background_emissions(cycle)
 
     def run(inputs: list):
         input = inputs[0]
@@ -109,12 +112,17 @@ def _run_input(cycle: dict):
         mappings = get_input_mappings(MODEL, cycle, input)
         has_mappings = len(mappings) > 0
 
+        # skip input that has background emissions we have already gap-filled (model run before)
+        has_no_gap_filled_background_emissions = no_gap_filled_background_emissions_func(input)
+
         logRequirements(cycle, model=MODEL, term=input_term_id,
                         has_ecoinvent_mappings=has_mappings,
                         ecoinvent_mappings=';'.join([v[0] for v in mappings]),
+                        has_no_gap_filled_background_emissions=has_no_gap_filled_background_emissions,
+                        termType_electricityFuel_complete=electricity_complete,
                         input_value=input_value)
 
-        should_run = all([electricity_complete, has_mappings, input_value])
+        should_run = all([electricity_complete, has_mappings, has_no_gap_filled_background_emissions, input_value])
         logShouldRun(cycle, MODEL, input_term_id, should_run, methodTier=TIER)
 
         grouped_emissions = reduce(_add_emission(cycle, input), mappings, {}) if should_run else {}
