@@ -1,8 +1,3 @@
-"""
-Aware Water Basin ID
-
-This model calculates the the [AWARE](https://wulca-waterlca.org/) water basin identifier.
-"""
 from hestia_earth.models.log import logRequirements, logShouldRun
 from .utils import download, has_geospatial_data, should_download
 from . import MODEL
