@@ -1,8 +1,9 @@
-from hestia_earth.utils.api import download_hestia
+from hestia_earth.schema import TermTermType
 from hestia_earth.utils.model import linked_node
 
 from hestia_earth.models.log import debugValues, logRequirements, logShouldRun
 from .utils import download, has_coordinates
+from hestia_earth.models.utils.term import download_term
 from . import MODEL
 
 REQUIREMENTS = {
@@ -30,7 +31,7 @@ def _download_region(site: dict):
         only_coordinates=True
     )
     try:
-        return None if gadm_id is None else linked_node(download_hestia(f"GADM-{gadm_id}"))
+        return None if gadm_id is None else linked_node(download_term(f"GADM-{gadm_id}", TermTermType.REGION))
     except Exception:
         return None
 
