@@ -1,13 +1,17 @@
 import os
+import json
+from area import area
+from functools import reduce, lru_cache
 from hestia_earth.schema import TermTermType
-from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.tools import non_empty_list
 
 from hestia_earth.models.log import debugValues, logErrorRun, logRequirements
 from hestia_earth.models.utils.site import cached_value, region_factor, region_level_1_id
+from hestia_earth.models.utils.term import download_term
 from . import MODEL
 
 MAX_AREA_SIZE = int(os.getenv('MAX_AREA_SIZE', '5000'))
+_ENABLE_CACHE_BOUNDARY_AREA = os.getenv('CACHE_BOUNDARY_AREA', 'false') == 'true'
 CACHE_VALUE = MODEL
 CACHE_AREA_SIZE = 'areaSize'
 GEOPANDAS_COLLECTION_NAME = {
@@ -83,35 +87,47 @@ def geospatial_data(site: dict, only_coordinates=False):
     })
 
 
-def _get_boundary_area_size(boundary: dict):
-    try:
-        from hestia_earth.earth_engine.boundary import get_size_km2
-    except ImportError:
-        raise ImportError("Run `pip install hestia_earth.earth_engine` to use this functionality")
+def _geojson_area_size(boundary: dict):
+    return (
+        _geojson_area_size(boundary.get('geometry')) if 'geometry' in boundary else
+        reduce(lambda p, c: p + _geojson_area_size(c), boundary.get('features'), 0) if 'features' in boundary
+        else area(boundary) / 1_000_000
+    )
 
+
+@lru_cache()
+def _cached_boundary_area_size(boundary: str):
     try:
-        return get_size_km2(boundary)
+        return _geojson_area_size(json.loads(boundary))
     except Exception:
         return None
 
 
+def _get_boundary_area_size(boundary: dict):
+    return _cached_boundary_area_size(
+        boundary=json.dumps(boundary)
+    ) if _ENABLE_CACHE_BOUNDARY_AREA else _geojson_area_size(boundary=boundary)
+
+
 def _get_region_area_size(site: dict):
     term = site.get('region', site.get('country'))
-    return term.get('area', (download_hestia(term.get('@id')) or {}).get('area')) if term else None
+    return term.get('area', (download_term(term.get('@id'), TermTermType.REGION) or {}).get('area')) if term else None
 
 
 def get_area_size(site: dict):
-    return None if has_coordinates(site) else (
-        # fallback if `boundary` provided but no `boundaryArea` was computed
-        site.get('boundaryArea') or _get_boundary_area_size(site.get('boundary'))
-    ) if has_boundary(site) else _get_region_area_size(site)
+    return _cached_value(site, CACHE_AREA_SIZE) or (
+        None if has_coordinates(site) else (
+            # fallback if `boundary` provided but no `boundaryArea` was computed
+            site.get('boundaryArea') or _get_boundary_area_size(site.get('boundary'))
+        ) if has_boundary(site) else _get_region_area_size(site)
+    )
 
 
 def _is_below_max_size(term: str, site: dict) -> bool:
     current_size = _cached_value(site, CACHE_AREA_SIZE) or get_area_size(site)
     if current_size is not None:
         logRequirements(site, model=MODEL, term=term,
-                        current_size=int(current_size),
+                        current_size=round(float(current_size), 5),
                         max_area_size=MAX_AREA_SIZE)
         return current_size <= MAX_AREA_SIZE
     return True
@@ -153,11 +169,11 @@ def _get_cached_data(term: str, site: dict, data: dict):
     cache = _cached_value(site, term)
     cache_sub_key = _cache_sub_key(data)
     # data can be grouped by year when required
-    value = cache.get(cache_sub_key) if (
-        isinstance(cache, dict) and cache_sub_key in cache and cache is not None
-     ) else cache
-    if value is not None:
-        debugValues(site, model=MODEL, term=term, value_from_cache=value)
+    value = cache.get(cache_sub_key) if all([
+        isinstance(cache, dict),
+        cache_sub_key
+    ]) else cache
+    debugValues(site, model=MODEL, term=term, value_from_cache=value)
     return value
 
 
