@@ -11,11 +11,12 @@ from hestia_earth.utils.model import filter_list_term_type
 from hestia_earth.utils.tools import safe_parse_float, to_precision
 
 from hestia_earth.models.log import logRequirements, log_as_table, logShouldRun
+from hestia_earth.models.utils import _omit
 from hestia_earth.models.utils.constant import DAYS_IN_YEAR
 from hestia_earth.models.utils.management import _new_management
 from hestia_earth.models.utils.term import get_lookup_value
 from hestia_earth.models.utils.lookup import get_region_lookup_value
-from hestia_earth.models.utils.blank_node import _node_date, DatestrFormat, _gapfill_datestr, DatestrGapfillMode
+from hestia_earth.models.utils.blank_node import DatestrFormat, _gapfill_datestr, DatestrGapfillMode
 from .utils import (
     IPCC_LAND_USE_CATEGORY_ANNUAL,
     IPCC_LAND_USE_CATEGORY_PERENNIAL,
@@ -40,7 +41,7 @@ REQUIREMENTS = {
             "permanent pasture",
             "other natural vegetation"
         ],
-        "country": "",
+        "country": {"@type": "Term", "termType": "region"},
         "management": [
             {
                 "@type": "Management",
@@ -56,11 +57,7 @@ REQUIREMENTS = {
 }
 RETURNS = {
     "Management": [{
-        "@type": "Management",
         "term.termType": "landCover",
-        "term.@id": [
-            "Forest", "Annual cropland", "Permanent cropland", "Permanent pasture", "Other natural vegetation"
-        ],
         "value": "",
         "endDate": "",
         "startDate": ""
@@ -95,6 +92,7 @@ SITE_TYPES = {
 DEFAULT_WINDOW_IN_YEARS = 20
 DATE_TOLERANCE_IN_YEARS = 2
 OUTPUT_SIGNIFICANT_DIGITS = 3
+ALLOWED_LAND_USE_TYPES = [ANNUAL_CROPLAND, PERMANENT_CROPLAND, PERMANENT_PASTURE]
 _LOOKUP_EXPANSION = "region-crop-cropGroupingFaostatProduction-areaHarvestedUpTo20YearExpansion.csv"
 
 
@@ -150,7 +148,7 @@ def cap_values(dictionary: dict, lower_limit: float = 0, upper_limit: float = 1)
 
 def site_area_sum_to_100(dict_of_percentages: dict):
     return False if dict_of_percentages == {} else (
-        math.isclose(sum(dict_of_percentages.values()), 1.0, rel_tol=0.01) or
+        math.isclose(sum(dict_of_percentages.values()), 1.0, rel_tol=0.05) or
         math.isclose(sum(dict_of_percentages.values()), 0.0, rel_tol=0.01)
     )
 
@@ -165,7 +163,7 @@ def _should_group_landCover(management_node: dict):
     )
 
 
-def get_changes(country_id: str, end_year: int) -> tuple[dict, bool]:
+def _get_changes(country_id: str, end_year: int) -> tuple[dict, bool]:
     """
     For each entry in ALL_LAND_USE_TERMS, creates a key: value in output dictionary, also TOTAL
     """
@@ -180,7 +178,7 @@ def get_changes(country_id: str, end_year: int) -> tuple[dict, bool]:
         )
         for land_use_term in ALL_LAND_USE_TERMS + [LAND_AREA]
     }
-    missing_changes = any(val is None for val in changes_dict.values())
+    missing_changes = [k for k, v in changes_dict.items() if v is None]
     changes_dict = {k: v if v is not None else 0 for k, v in changes_dict.items()}
     changes_dict[TOTAL_AGRICULTURAL_CHANGE] = (
         float(changes_dict.get(TOTAL_CROPLAND, 0)) + float(changes_dict.get(PERMANENT_PASTURE, 0))
@@ -412,8 +410,15 @@ def _get_faostat_name(term: dict) -> str:
     return _get_lookup_with_cache(term, "cropGroupingFaostatArea")
 
 
+def _get_most_common_or_alphabetically_first(crop_terms: list) -> str:
+    histogram = {term: crop_terms.count(term) for term in crop_terms}
+    max_freq = max(histogram.values())
+    # Sorted; to be deterministic
+    return sorted([term for term, freq in histogram.items() if freq == max_freq])[0]
+
+
 def _get_complete_faostat_to_crop_mapping() -> dict:
-    """Returns mapping in the format: {faostat_name: IPPC_LAND_USE_CATEGORY, ...}"""
+    """Returns mapping in the format: {faostat_name: IPCC_LAND_USE_CATEGORY, ...}"""
     lookup = download_lookup("crop.csv")
     mappings = defaultdict(list)
     for crop_term_id in [row[0] for row in lookup]:
@@ -423,7 +428,7 @@ def _get_complete_faostat_to_crop_mapping() -> dict:
         if key:
             mappings[key].append(crop_ipcc_land_use_category(crop_term_id=crop_term_id, lookup_term_type="crop"))
     return {
-        fao_name: max(set(crop_terms), key=crop_terms.count)
+        fao_name: _get_most_common_or_alphabetically_first(crop_terms)
         for fao_name, crop_terms in mappings.items()
     }
 
@@ -576,6 +581,14 @@ def _get_year_from_landCover(node: dict):
     return int(date[:4])
 
 
+def _scale_site_area_errors(site_area: dict) -> dict:
+    """Redistribute the result of any rounding error in proportion to the other land use types."""
+    # Positive errors would not have been capped, so won't be missing.
+    negative_errors = [v for v in site_area.values() if v < 0.0]
+    return {k: v + negative_errors[0] * v for k, v in site_area.items()} \
+        if negative_errors and abs(negative_errors[0]) < 1 and all([v < 1 for v in site_area.values()]) else site_area
+
+
 def _should_run_historical_land_use_change(site: dict, nodes: list, land_use_type: str) -> tuple[bool, dict]:
     # Assume a single management node for single-cropping.
     return _should_run_historical_land_use_change_single_crop(
@@ -596,7 +609,7 @@ def _should_run_historical_land_use_change_single_crop(
 ) -> tuple[bool, dict]:
     """Calculate land use change percentages for a single management node/crop."""
     # (C-H).
-    changes, missing_changes = get_changes(country_id=country_id, end_year=end_year)
+    changes, missing_changes = _get_changes(country_id=country_id, end_year=end_year)
 
     # (L). Estimate maximum forest loss
     forest_loss = _estimate_maximum_forest_change(
@@ -723,7 +736,7 @@ def _should_run_historical_land_use_change_single_crop(
         if land_type != land_use_type
     }
     site_area[land_use_type] = 1 - sum(site_area.values())
-    capped_site_area = cap_values(dictionary=site_area, lower_limit=0, upper_limit=1)
+    capped_site_area = cap_values(dictionary=_scale_site_area_errors(site_area))
 
     sum_of_site_areas_is_100 = site_area_sum_to_100(capped_site_area)
     site_type_allowed = site.get("siteType") in SITE_TYPES
@@ -736,12 +749,13 @@ def _should_run_historical_land_use_change_single_crop(
         land_use_type=land_use_type,
         country_id=country_id,
         changes=log_as_table(changes),
+        missing_changes=log_as_table(missing_changes),
         site_area=log_as_table(capped_site_area),
         sum_of_site_areas_is_100=sum_of_site_areas_is_100,
         site_type_allowed=site_type_allowed
     )
 
-    should_run = all([not missing_changes, country_id, site_type_allowed, sum_of_site_areas_is_100])
+    should_run = all([len(missing_changes) == 0, country_id, site_type_allowed, sum_of_site_areas_is_100])
     logShouldRun(site, MODEL, term.get("@id"), should_run, model_key=MODEL_KEY)
 
     return should_run, capped_site_area
@@ -755,64 +769,77 @@ def _collect_land_use_types(nodes: list) -> list:
     """Look up the land use type from management nodes."""
     return [
         {
+            "value": node.get("value", ""),
+            "term": node.get("term", {}),
             "id": node.get("term", {}).get("@id"),
             "land-use-type": _get_land_use_term_from_node(node),
-            "endDate": _gapfill_datestr(datestr=node.get("endDate"), mode=DatestrGapfillMode.END)[:10]
+            "endDate": _gapfill_datestr(datestr=node.get("endDate"), mode=DatestrGapfillMode.END)[:10],
+            "startDate": _gapfill_datestr(datestr=node.get("startDate"), mode=DatestrGapfillMode.START)[:10]
         } for node in nodes
     ]
 
 
-def _no_prior_land_cover_data(nodes: list, end_date: str) -> bool:
+def _no_prior_land_cover_data(nodes: list, target_node: dict) -> bool:
+    """
+    Returns true if there are no nodes whose start & end dates the target_node falls within,
+    including a tolerance.
+    """
     target_date = (
-        datetime.strptime(end_date, DatestrFormat.YEAR_MONTH_DAY.value)
+        datetime.strptime(target_node.get('startDate') or target_node.get('endDate'),
+                          DatestrFormat.YEAR_MONTH_DAY.value)
         - timedelta(days=DEFAULT_WINDOW_IN_YEARS * DAYS_IN_YEAR)
     )
+    tolerance = timedelta(days=DATE_TOLERANCE_IN_YEARS * DAYS_IN_YEAR)
     previous_nodes = [
         node for node in nodes
-        if abs(_node_date(node) - target_date) < timedelta(days=DATE_TOLERANCE_IN_YEARS * DAYS_IN_YEAR)
+        if datetime.strptime(node.get("startDate"), DatestrFormat.YEAR_MONTH_DAY.value) - tolerance
+        < target_date <
+        datetime.strptime(node.get("endDate"), DatestrFormat.YEAR_MONTH_DAY.value) + tolerance
     ]
     return len(previous_nodes) == 0
 
 
-def _should_run(site: dict, management_nodes: list) -> tuple[bool, dict]:
-    summarised_nodes = _collect_land_use_types(management_nodes)
-    allowed_land_use_types = [ANNUAL_CROPLAND, PERMANENT_CROPLAND, PERMANENT_PASTURE]
+def _should_run(site: dict) -> tuple[bool, list, dict]:
+    management_nodes = _collect_land_use_types(
+        [
+            node for node in filter_list_term_type(site.get("management", []), TermTermType.LANDCOVER)
+            if not _should_group_landCover(node)
+        ]
+    )
     relevant_nodes = sorted(
         [
-            node for node in summarised_nodes
-            if node["land-use-type"] in allowed_land_use_types
+            node for node in management_nodes
+            if node["land-use-type"] in ALLOWED_LAND_USE_TYPES
         ],
-        key=lambda n: n.get("endDate")
+        key=lambda n: n.get("startDate") or n.get("endDate")
     )
+
     land_use_type = relevant_nodes[0].get("land-use-type") if relevant_nodes else None
 
     has_no_prior_land_cover_data = _no_prior_land_cover_data(
         nodes=management_nodes,
-        end_date=relevant_nodes[-1:][0].get("endDate")
+        target_node=relevant_nodes[0]
     ) if relevant_nodes else None
 
     should_run_nodes, site_area = _should_run_historical_land_use_change(
         site=site,
-        nodes=management_nodes,
+        nodes=relevant_nodes,
         land_use_type=land_use_type
     ) if all([land_use_type, has_no_prior_land_cover_data]) else (False, {})
 
     logRequirements(site, model=MODEL, model_key=MODEL_KEY,
-                    has_management_nodes=bool(management_nodes),
+                    has_management_nodes=bool(relevant_nodes),
                     land_use_type=land_use_type,
-                    allowed_land_use_types=';'.join(allowed_land_use_types),
+                    allowed_land_use_types=';'.join(ALLOWED_LAND_USE_TYPES),
                     has_no_prior_land_cover_data=has_no_prior_land_cover_data,
-                    summarised_nodes=log_as_table(summarised_nodes))
+                    management_nodes=log_as_table([_omit(n, ['term']) for n in relevant_nodes]),
+                    should_run_nodes=should_run_nodes)
 
     should_run = all([land_use_type, has_no_prior_land_cover_data, should_run_nodes])
     logShouldRun(site, MODEL, None, should_run, model_key=MODEL_KEY)
-    return should_run_nodes, site_area
+    return should_run_nodes, relevant_nodes, site_area
 
 
 def run(site: dict) -> list:
-    management_nodes = [
-        node for node in filter_list_term_type(site.get("management", []), TermTermType.LANDCOVER)
-        if not _should_group_landCover(node)
-    ]
-    should_run, site_area = _should_run(site=site, management_nodes=management_nodes)
-    return _run(site, management_nodes, site_area) if should_run else []
+    should_run, relevant_nodes, site_area = _should_run(site=site)
+    return _run(site, relevant_nodes, site_area) if should_run else []
