@@ -2,7 +2,8 @@ from .resourceUse_utils import run_resource_use
 
 REQUIREMENTS = {
     "ImpactAssessment": {
-        "Site": {
+        "site": {
+            "@type": "Site",
             "management": [{"@type": "Management", "value": ">=0", "term.termType": "landCover", "endDate": ""}]
         },
         "emissionsResourceUse": [
@@ -26,6 +27,9 @@ RETURNS = {
         "previousLandCover": ""
     }]
 }
+LOOKUPS = {
+    "crop": "IPCC_LAND_USE_CATEGORY"
+}
 TERM_ID = 'landTransformation100YearAverageDuringCycle'
 _HISTORIC_DATE_OFFSET = 100
 
