@@ -20,7 +20,7 @@ REQUIREMENTS = {
     }
 }
 LOOKUPS = {
-    "region-liveAnimal-pregnancyRateTotal": "pregnancy rate"
+    "region-liveAnimal-pregnancyRateTotal": ""
 }
 RETURNS = {
     "Animal": [{
