@@ -9,10 +9,10 @@ REQUIREMENTS = {
         "animals": [{
             "@type": "Animal",
             "term.termType": "liveAnimal",
-            "practices": {
+            "practices": [{
                 "@type": "Practice",
                 "term.termType": "animalManagement"
-            }
+            }]
         }]
     }
 }
