@@ -3,20 +3,18 @@ from functools import reduce
 from numpy import average, copy, random, vstack
 from numpy.typing import NDArray
 from typing import Optional, Union
-
 from hestia_earth.schema import (
     MeasurementMethodClassification,
     MeasurementStatsDefinition,
     SiteSiteType
 )
-
 from hestia_earth.utils.tools import non_empty_list
+from hestia_earth.utils.stats import gen_seed
+from hestia_earth.utils.descriptive_stats import calc_descriptive_stats
 
 from hestia_earth.models.log import log_as_table, logRequirements, logShouldRun
 from hestia_earth.models.utils import pairwise
-from hestia_earth.models.utils.array_builders import gen_seed
 from hestia_earth.models.utils.blank_node import group_nodes_by_year
-from hestia_earth.models.utils.descriptive_stats import calc_descriptive_stats
 from hestia_earth.models.utils.ecoClimateZone import EcoClimateZone, get_eco_climate_zone_value
 from hestia_earth.models.utils.source import get_source
 from hestia_earth.models.utils.measurement import _new_measurement
@@ -551,7 +549,7 @@ def _measurement(
         "dates": [f"{year}-12-31" for year in timestamps],
         "methodClassification": _METHOD_CLASSIFICATION
     }
-    measurement = _new_measurement(TERM_ID) | {
+    measurement = _new_measurement(TERM_ID, MODEL) | {
         key: value for key, value in update_dict.items() if value
     }
     measurement["depthUpper"] = _DEPTH_UPPER
