@@ -89,7 +89,8 @@ def _get_excreta_b0(country: dict, input: dict):
     data_values = get_region_lookup_value(lookup_name, country.get('@id'), term_id, model=MODEL, term=TERM_ID)
     return safe_parse_float(
         extract_grouped_data(data_values, productivity_key.value) or
-        extract_grouped_data(data_values, PRODUCTIVITY.HIGH.value)  # defaults to high if low is not found
+        extract_grouped_data(data_values, PRODUCTIVITY.HIGH.value),  # defaults to high if low is not found
+        default=None
     )
 
 
@@ -100,7 +101,8 @@ def _get_excretaManagement_MCF_from_lookup(term_id: str, ecoClimateZone: int, du
     debugMissingLookup(lookup_name, 'termid', term_id, ecoClimateZone, data_values, model=MODEL, term=TERM_ID)
     return safe_parse_float(
         extract_grouped_data(data_values, duration_key.value)
-        or extract_grouped_data(data_values, DEFAULT_DURATION.value)  # defaults to 12 months if no duration specified
+        or extract_grouped_data(data_values, DEFAULT_DURATION.value),  # defaults to 12 months if no duration specified
+        default=None
     ) if data_values else 0
 
 
