@@ -2,7 +2,6 @@
 Utilities for calculating CO2 emissions based on changes in carbon stocks (e.g., `organicCarbonPerHa`,
 `aboveGroundBiomass` and `belowGroundBiomass`).
 """
-
 from datetime import datetime, timedelta
 from enum import Enum
 from functools import reduce
@@ -11,22 +10,21 @@ from numpy import array, random, mean
 from numpy.typing import NDArray
 from pydash.objects import merge
 from typing import Any, Callable, NamedTuple, Optional, Union
-
 from hestia_earth.schema import (
     EmissionMethodTier, EmissionStatsDefinition, MeasurementMethodClassification
 )
 from hestia_earth.utils.date import diff_in_days, YEAR
 from hestia_earth.utils.tools import flatten, non_empty_list, safe_parse_date
+from hestia_earth.utils.stats import correlated_normal_2d, gen_seed
+from hestia_earth.utils.descriptive_stats import calc_descriptive_stats
 
 from hestia_earth.models.log import log_as_table
 from hestia_earth.models.utils import pairwise
-from hestia_earth.models.utils.array_builders import correlated_normal_2d, gen_seed
 from hestia_earth.models.utils.blank_node import (
     _gapfill_datestr, _get_datestr_format, DatestrGapfillMode, DatestrFormat, group_nodes_by_year, node_term_match,
     split_node_by_dates
 )
 from hestia_earth.models.utils.constant import Units, get_atomic_conversion
-from hestia_earth.models.utils.descriptive_stats import calc_descriptive_stats
 from hestia_earth.models.utils.emission import min_emission_method_tier
 from hestia_earth.models.utils.measurement import (
     group_measurements_by_method_classification, min_measurement_method_classification,
@@ -319,7 +317,13 @@ def _add_carbon_stock_change_emissions(
     value = emission_1.value + emission_2.value
     start_date = min(emission_1.start_date, emission_2.start_date)
     end_date = max(emission_1.end_date, emission_2.end_date)
-    method = min_emission_method_tier(emission_1.method, emission_2.method)
+
+    methods = [
+        method for emission in (emission_1, emission_2)
+        if isinstance((method := emission.method), EmissionMethodTier)
+    ]
+
+    method = min_emission_method_tier(*methods) if methods else None
 
     return CarbonStockChangeEmission(value, start_date, end_date, method)
 
@@ -442,7 +446,6 @@ def create_should_run_function(
 
         inventory, inventory_logs = (
             compile_inventory_func(
-                cycle_id,
                 cycles,
                 carbon_stock_measurements,
                 land_cover_nodes
@@ -464,7 +467,8 @@ def create_should_run_function(
         logs = should_compile_logs | inventory_logs | {
             "seed": seed,
             "has_valid_inventory": has_valid_inventory,
-            "has_consecutive_years": has_consecutive_years
+            "has_consecutive_years": has_consecutive_years,
+            "has_stock_measurements": bool(carbon_stock_measurements)
         }
 
         return should_run_, kwargs, logs
@@ -554,7 +558,6 @@ def _create_compile_inventory_function(
         The `compile_inventory` function.
     """
     def compile_inventory(
-        cycle_id: str,
         cycles: list[dict],
         carbon_stock_measurements: list[dict],
         land_cover_nodes: list[dict]
@@ -796,26 +799,8 @@ def _preprocess_carbon_stocks(
     list[CarbonStock]
         A list of carbon stocks sorted by date.
     """
-    sorted_measurements = sorted(
-        flatten([split_node_by_dates(m) for m in carbon_stock_measurements]),
-        key=lambda node: _gapfill_datestr(node["dates"][0], DatestrGapfillMode.END)
-    )
-
-    values = flatten(node["value"] for node in sorted_measurements)
-
-    sds = flatten(
-        node.get("sd", []) or [_calc_nominal_sd(v, _NOMINAL_ERROR) for v in node["value"]]
-        for node in sorted_measurements
-    )
-
-    dates = flatten(
-        [_gapfill_datestr(datestr, DatestrGapfillMode.END) for datestr in node["dates"]]
-        for node in sorted_measurements
-    )
-
-    methods = flatten(
-        [MeasurementMethodClassification(node.get("methodClassification")) for _ in node["value"]]
-        for node in sorted_measurements
+    dates, values, sds, methods = _extract_node_data(
+        flatten([split_node_by_dates(m) for m in carbon_stock_measurements])
     )
 
     correlation_matrix = compute_time_series_correlation_matrix(
@@ -842,6 +827,35 @@ def _preprocess_carbon_stocks(
     ]
 
 
+def _extract_node_data(nodes: list[dict]) -> list[dict]:
+
+    def group_node(result, node) -> dict[str, dict]:
+        date = _gapfill_datestr(node["dates"][0], DatestrGapfillMode.END)
+        result[date] = result.get(date, []) + [node]
+        return result
+
+    grouped_nodes = reduce(group_node, nodes, dict())
+
+    def get_values(date):
+        return flatten(node.get("value", []) for node in grouped_nodes[date])
+
+    def get_sds(date):
+        return flatten(
+            node.get("sd", []) or [_calc_nominal_sd(v, _NOMINAL_ERROR) for v in node.get("value", [])]
+            for node in grouped_nodes[date]
+        )
+
+    def get_methods(date):
+        return flatten(node.get("methodClassification", []) for node in grouped_nodes[date])
+
+    dates = sorted(grouped_nodes.keys())
+    values = [mean(get_values(date)) for date in dates]
+    sds = [mean(get_sds(date)) for date in dates]
+    methods = [min_measurement_method_classification(get_methods(date)) for date in dates]
+
+    return dates, values, sds, methods
+
+
 def _calc_nominal_sd(value: float, error: float) -> float:
     """
     Calculate a nominal SD for a carbon stock measurement. Can be used to gap fill SD when information not present in
@@ -1166,20 +1180,19 @@ def _squash_inventory(
         return _InventoryKey.CO2_EMISSION in carbon_stock_inventory.get(method, {}).get(year, {}).keys()
 
     def squash(result: dict, year: int) -> dict:
-        update_dict = next(
-            (
-                {
-                    year: {
-                        **_get_land_use_change_data(year, land_use_inventory),
-                        **reduce(merge, [
-                            carbon_stock_inventory.get(method, {}).get(year, {}),
-                            cycle_inventory.get(year, {})
-                        ], dict())
-                    }
-                } for method in measurement_method_ranking if should_run_group(method, year)
-            ),
-            {}
+        method = next(
+            (method for method in measurement_method_ranking if should_run_group(method, year)),
+            None
         )
+        update_dict = {
+            year: {
+                **_get_land_use_change_data(year, land_use_inventory),
+                **reduce(merge, [
+                    carbon_stock_inventory.get(method, {}).get(year, {}),
+                    cycle_inventory.get(year, {})
+                ], dict())
+            }
+        }
         return result | update_dict
 
     return reduce(squash, inventory_years, dict())
@@ -1415,36 +1428,31 @@ def create_run_function(
         Assign emissions to either the land use or management change term ids and sum together.
         """
         data = inventory[year]
+
         years_since_luc_event = data[_InventoryKey.YEARS_SINCE_LUC_EVENT]
         years_since_inventory_start = data[_InventoryKey.YEARS_SINCE_INVENTORY_START]
+        share_of_emission = data[_InventoryKey.SHARE_OF_EMISSION][cycle_id]
 
+        co2_emission = data.get(_InventoryKey.CO2_EMISSION)
+
+        has_co2_emission = bool(co2_emission)
         is_luc_emission = bool(years_since_luc_event) and years_since_luc_event <= _TRANSITION_PERIOD_YEARS
         is_data_complete = bool(years_since_inventory_start) and years_since_inventory_start >= _TRANSITION_PERIOD_YEARS
 
-        if is_luc_emission:
-            # If LUC emission allocate emissions to land use change AND add corresponding zero emission to management
-            emission_term_id = land_use_change_emission_term_id
-            zero_emission_term_id = management_change_emission_term_id
-        elif is_data_complete:
-            # If management emission && data complete allocate emissions to management change AND add corresponding
-            # zero emission to management
-            emission_term_id = management_change_emission_term_id
-            zero_emission_term_id = land_use_change_emission_term_id
-        else:
-            # If management emission, but not data complete allocate emissions to management change only
-            emission_term_id = management_change_emission_term_id
-            zero_emission_term_id = None
+        emission_term_id = (
+            land_use_change_emission_term_id if is_luc_emission else management_change_emission_term_id
+        ) if has_co2_emission else None
 
-        rescaled_emission = _rescale_carbon_stock_change_emission(
-            data[_InventoryKey.CO2_EMISSION], data[_InventoryKey.SHARE_OF_EMISSION][cycle_id]
+        zero_emission_term_id = (
+            management_change_emission_term_id if is_luc_emission else
+            (land_use_change_emission_term_id if is_data_complete else None)
         )
 
-        zero_emission = CarbonStockChangeEmission(
-            value=array(0),
-            start_date=rescaled_emission.start_date,
-            end_date=rescaled_emission.end_date,
-            method=rescaled_emission.method
-        ) if zero_emission_term_id else None
+        rescaled_emission = _rescale_carbon_stock_change_emission(
+            co2_emission, share_of_emission
+        ) if emission_term_id else None
+
+        zero_emission = get_zero_emission(year) if zero_emission_term_id else None
 
         previous_emission = result.get(emission_term_id)
         previous_zero_emission = result.get(zero_emission_term_id)
@@ -1454,7 +1462,7 @@ def create_run_function(
                 _add_carbon_stock_change_emissions(previous_emission, rescaled_emission) if previous_emission
                 else rescaled_emission
             )
-        }
+        } if emission_term_id else {}
 
         zero_emission_dict = {
             zero_emission_term_id: (
@@ -1497,7 +1505,7 @@ def create_run_function(
         return [
             new_emission_func(
                 term_id=emission_term_id,
-                method_tier=total_emission.method,
+                method_tier=_get_emission_method(total_emission),
                 start_date=_get_emission_start_date(total_emission, cycle_start_date),
                 end_date=_get_emission_end_date(total_emission, cycle_end_date),
                 **calc_descriptive_stats(
@@ -1506,18 +1514,33 @@ def create_run_function(
                     decimals=6
                 )
             ) for emission_term_id, total_emission in assigned_emissions.items()
+            if isinstance(total_emission, CarbonStockChangeEmission)
         ]
 
     return run
 
 
+def get_zero_emission(year):
+    return CarbonStockChangeEmission(
+        value=array(0),
+        start_date=_gapfill_datestr(year),
+        end_date=_gapfill_datestr(year, DatestrGapfillMode.END),
+        method=None
+    )
+
+
+def _get_emission_method(emission: CarbonStockChangeEmission):
+    method = emission.method
+    return method if isinstance(method, EmissionMethodTier) else EmissionMethodTier.TIER_1
+
+
 def _get_emission_start_date(emission: CarbonStockChangeEmission, cycle_start_date: str) -> str:
     cycle_datetime = safe_parse_date(_gapfill_datestr(cycle_start_date))
     emission_datetime = safe_parse_date(emission.start_date)
 
     should_run = (
         cycle_datetime and emission_datetime
-        and cycle_datetime <= emission_datetime  # If the cycle starts before the emission, add a `startDate`
+        and cycle_datetime < emission_datetime  # If the cycle starts before the emission, add a `startDate`
     )
 
     return (
@@ -1527,12 +1550,12 @@ def _get_emission_start_date(emission: CarbonStockChangeEmission, cycle_start_da
 
 
 def _get_emission_end_date(emission: CarbonStockChangeEmission, cycle_end_date: str) -> str:
-    cycle_datetime = safe_parse_date(_gapfill_datestr(cycle_end_date))
+    cycle_datetime = safe_parse_date(_gapfill_datestr(cycle_end_date, DatestrGapfillMode.END))
     emission_datetime = safe_parse_date(emission.end_date)
 
     should_run = (
         cycle_datetime and emission_datetime
-        and cycle_datetime >= emission_datetime  # If the cycle ends after the emission, add an `endDate`
+        and cycle_datetime > emission_datetime  # If the cycle ends after the emission, add an `endDate`
     )
 
     return (
