@@ -4,15 +4,14 @@ from itertools import product
 import numpy as np
 import numpy.typing as npt
 from typing import Any, Callable, Literal, Optional, TypedDict, Union
-
 from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition, SiteSiteType
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 from hestia_earth.utils.tools import safe_parse_float
+from hestia_earth.utils.stats import gen_seed, repeat_single, truncated_normal_1d
+from hestia_earth.utils.descriptive_stats import calc_descriptive_stats
 
 from hestia_earth.models.log import debugMissingLookup, log_as_table, logRequirements, logShouldRun
-from hestia_earth.models.utils.array_builders import gen_seed, repeat_single, truncated_normal_1d
 from hestia_earth.models.utils.blank_node import group_nodes_by_year
-from hestia_earth.models.utils.descriptive_stats import calc_descriptive_stats
 from hestia_earth.models.utils.ecoClimateZone import EcoClimateZone, get_eco_climate_zone_value
 from hestia_earth.models.utils.emission import _new_emission
 from hestia_earth.models.utils.lookup import get_region_lookup_value
@@ -24,6 +23,7 @@ from .biomass_utils import BiomassCategory, get_valid_management_nodes, summaris
 REQUIREMENTS = {
     "Cycle": {
         "site": {
+            "@type": "Site",
             "management": [
                 {
                     "@type": "Management",
@@ -155,8 +155,6 @@ _Inventory = dict[int, _InventoryYear]
 {year (int): data (_InventoryYear)}
 """
 
-_EmissionInventory = dict[_EmissionTermId, npt.NDArray]
-
 
 _BIOMASS_CATEGORY_TO_FUEL_CATEGORY = {
     BiomassCategory.FOREST: {
@@ -315,7 +313,9 @@ def _get_fuel_factor(fuel_category: _FuelCategory) -> dict:
         debugMissingLookup(LOOKUP_FILENAME, "FuelCategory", row, target, data.get(target), model=MODEL, term=term_id)
 
     return (
-        {k: parsed for k, v in data.items() if (parsed := safe_parse_float(v, None)) is not None}  # remove missing
+        {
+            k: parsed for k, v in data.items() if (parsed := safe_parse_float(v, default=None)) is not None
+        }  # remove missing
         or _DEFAULT_FACTOR  # if parsed dict empty, return default
     )
 
@@ -344,7 +344,9 @@ def _get_emission_factor(term_id: _EmissionTermId, emission_category: _EmissionC
         )
 
     return (
-        {k: parsed for k, v in data.items() if (parsed := safe_parse_float(v, None)) is not None}  # remove missing
+        {
+            k: parsed for k, v in data.items() if (parsed := safe_parse_float(v, default=None)) is not None
+        }  # remove missing
         or _DEFAULT_FACTOR  # if parsed dict empty, return default
     )
 
@@ -517,9 +519,9 @@ def _sum_cycle_emissions(term_id: _EmissionTermId, cycle_id: str, inventory: _In
     return reduce(add_cycle_emissions, inventory.keys(), np.array(0))
 
 
-def _compile_run_data(
+def _compile_inventory(
     cycle: dict, site: dict, land_cover_nodes: list[dict], eco_climate_zone: EcoClimateZone
-) -> tuple[_EmissionInventory, _Inventory, dict]:
+):
     """
     Compile the run data for the model, collating data from `site.management` and related cycles. An annualised
     inventory of land cover change and natural vegetation burning events is constructed. Emissions from burning events
@@ -538,18 +540,12 @@ def _compile_run_data(
 
     Returns
     -------
-    emission_inventory : _EmissionInventory
-        A dictionary of emissions relevant to the cycle the model is run on, in the format:
-        ```
-        {
-            emission_term_id (str): value (NDArray),
-            ...
-        }
-        ```
+    should_run : bool
+        Whether the model should be run.
     inventory : _Inventory
-        An inventory of model data
+        An inventory of model data.
     logs : dict
-        Data from the compilation process that should be logged.
+        Data about the inventory compilation to be logged.
     """
     cycle_id = cycle.get("@id")
     related_cycles_ = related_cycles(site, cycles_mapping={cycle_id: cycle})
@@ -585,9 +581,15 @@ def _compile_run_data(
         Returns
         -------
         inventory : dict
-            An inventory of model data, updated to include the new model year.
+            An inventory of model data, updated to include the input year.
         """
-        land_cover_nodes = next((nodes for year_, nodes in land_cover_grouped.items() if year_ >= year), [])  # Backfill
+        land_cover_nodes = land_cover_grouped.get(
+            next(
+                (k for k in sorted(land_cover_grouped) if k >= year),  # backfill if possible
+                min(land_cover_grouped, key=lambda k: abs(k - year))   # else forward-fill
+            ),
+            []
+        )
 
         biomass_category_summary = summarise_land_cover_nodes(land_cover_nodes)
         prev_biomass_category_summary = inventory.get(year-1, {}).get("biomass_category_summary", {})
@@ -655,17 +657,17 @@ def _compile_run_data(
 
     inventory = reduce(build_inventory_year, range(min_year, max_year+1), dict())
 
-    emission_inventory = {
-        term_id: value for term_id in EMISSION_TERM_IDS
-        if np.all((value := _sum_cycle_emissions(term_id, cycle_id, inventory)) > 0)
-    }
+    n_land_cover_years = len(land_cover_grouped)
 
     logs = {
+        "n_land_cover_years": n_land_cover_years,
         "percent_burned": percent_burned,
         "seed": seed,
     }
 
-    return emission_inventory, inventory, logs
+    should_run = bool(inventory and n_land_cover_years > 1)
+
+    return should_run, inventory, logs
 
 
 def _format_bool(value: Optional[bool]) -> str:
@@ -830,23 +832,16 @@ def _format_inventory(term_id: _EmissionTermId, cycle_id: str, inventory: dict)
     ) if inventory else "None"
 
 
-def _should_run_emission(
-    term_id: _EmissionTermId, cycle: dict, emission_inventory: _EmissionInventory, inventory: dict, logs: dict
-):
+def _log_emission_data(should_run: bool, term_id: _EmissionTermId, cycle: dict, inventory: dict, logs: dict):
     """
-    Determine, based on the compiled data, whether the model should run for a specifc emission term id. Format and log
-    the model logs and inventory.
+    Format and log the model logs and inventory.
     """
-    should_run = term_id in emission_inventory
-
     formatted_logs = _format_logs(logs)
     formatted_inventory = _format_inventory(term_id, cycle.get("@id"), inventory)
 
     logRequirements(cycle, model=MODEL, term=term_id, **formatted_logs, inventory=formatted_inventory)
     logShouldRun(cycle, MODEL, term_id, should_run)
 
-    return should_run
-
 
 def _should_run(cycle: dict):
     """
@@ -860,8 +855,8 @@ def _should_run(cycle: dict):
 
     Returns
     -------
-    tuple[bool, dict]
-        should_run, emission_inventory
+    tuple[bool, _Inventory]
+        should_run, inventory
     """
     site = _get_site(cycle)
 
@@ -872,7 +867,7 @@ def _should_run(cycle: dict):
 
     has_valid_site_type = all([site_type, site_type not in _EXCLUDED_SITE_TYPES])
     has_valid_eco_climate_zone = all([eco_climate_zone, eco_climate_zone not in _EXCLUDED_ECO_CLIMATE_ZONES])
-    has_land_cover_nodes = len(land_cover_nodes) > 0
+    has_land_cover_nodes = len(land_cover_nodes) > 1
 
     should_compile_inventory = all([
         has_valid_site_type,
@@ -880,9 +875,9 @@ def _should_run(cycle: dict):
         has_land_cover_nodes
     ])
 
-    emission_inventory, inventory, compilation_logs = (
-        _compile_run_data(cycle, site, land_cover_nodes, eco_climate_zone)
-        if should_compile_inventory else ({}, {}, {})
+    should_run, inventory, compilation_logs = (
+        _compile_inventory(cycle, site, land_cover_nodes, eco_climate_zone)
+        if should_compile_inventory else (False, {}, {})
     )
 
     logs = {
@@ -896,21 +891,18 @@ def _should_run(cycle: dict):
         **compilation_logs
     }
 
-    should_run = all([
-        any([
-            _should_run_emission(term_id, cycle, emission_inventory, inventory, logs) for term_id in EMISSION_TERM_IDS
-        ])
-    ])
+    for term_id in EMISSION_TERM_IDS:
+        _log_emission_data(should_run, term_id, cycle, inventory, logs)
 
-    return should_run, emission_inventory
+    return should_run, inventory
 
 
-def _run_emission(term_id: _EmissionTermId, emissions: dict[_EmissionTermId, npt.NDArray]) -> list[dict]:
+def _run_emission(term_id: _EmissionTermId, cycle_id: str, inventory: _Inventory) -> list[dict]:
     """
-    Retrieve the pre-computed emissions and format them as a HESTIA
+    Retrieve the sum relevant emissions and format them as a HESTIA
     [Emission node](https://www.hestia.earth/schema/Emission).
     """
-    emission = emissions[term_id]
+    emission = _sum_cycle_emissions(term_id, cycle_id, inventory)
     descriptive_stats = calc_descriptive_stats(emission, STATS_DEFINITION, decimals=3)
     return _emission(term_id, **descriptive_stats)
 
@@ -931,5 +923,5 @@ def run(cycle: dict):
         `ch4ToAirNaturalVegetationBurning` **OR** `coToAirNaturalVegetationBurning` **OR**
         `n2OToAirNaturalVegetationBurningDirect` **OR** `noxToAirNaturalVegetationBurning`.
     """
-    should_run, emission_inventory = _should_run(cycle)
-    return [_run_emission(term_id, emission_inventory) for term_id in emission_inventory] if should_run else []
+    should_run, inventory = _should_run(cycle)
+    return [_run_emission(term_id, cycle.get("@id"), inventory) for term_id in EMISSION_TERM_IDS] if should_run else []
