@@ -3,23 +3,22 @@ from numpy import array, empty, exp, minimum, random, where, vstack
 from numpy.typing import NDArray
 from pydash.objects import merge
 from typing import Any, Callable, Union
-
 from hestia_earth.schema import (
     CycleFunctionalUnit, MeasurementMethodClassification, SiteSiteType, TermTermType
 )
 from hestia_earth.utils.model import find_term_match, filter_list_term_type
 from hestia_earth.utils.tools import flatten, list_sum, non_empty_list
 from hestia_earth.utils.blank_node import get_node_value
-
-from hestia_earth.models.utils.array_builders import (
+from hestia_earth.utils.stats import (
     avg_run_in_columnwise, gen_seed, grouped_avg, repeat_1d_array_as_columns
 )
+from hestia_earth.utils.descriptive_stats import calc_descriptive_stats
+
 from hestia_earth.models.utils.blank_node import (
     cumulative_nodes_lookup_match, cumulative_nodes_term_match, group_nodes_by_year, group_nodes_by_year_and_month,
     GroupNodesByYearMode, node_lookup_match, node_term_match
 )
 from hestia_earth.models.utils.cycle import check_cycle_site_ids_identical
-from hestia_earth.models.utils.descriptive_stats import calc_descriptive_stats
 from hestia_earth.models.utils.measurement import _new_measurement
 from hestia_earth.models.utils.property import get_node_property
 from hestia_earth.models.utils.site import related_cycles
@@ -33,11 +32,137 @@ from .organicCarbonPerHa_utils import (
 )
 from . import MODEL
 
-_LOOKUPS = {
+REQUIREMENTS = {
+    "Site": {
+        "siteType": "cropland",
+        "measurements": [
+            {
+                "@type": "Measurement",
+                "term.@id": "sandContent",
+                "value": "",
+                "depthUpper": "0",
+                "depthLower": "30",
+                "optional": {
+                    "dates": ""
+                }
+            },
+            {
+                "@type": "Measurement",
+                "term.@id": "temperatureMonthly",
+                "value": "",
+                "dates": ""
+            },
+            {
+                "@type": "Measurement",
+                "term.@id": "precipitationMonthly",
+                "value": "",
+                "dates": ""
+            },
+            {
+                "@type": "Measurement",
+                "term.@id": "potentialEvapotranspirationMonthly",
+                "value": "",
+                "dates": ""
+            }
+        ],
+        "related": {
+            "Cycle": [{
+                "endDate": "",
+                "products": [
+                    {
+                        "@type": "Product",
+                        "term.@id": [
+                            "aboveGroundCropResidueLeftOnField",
+                            "aboveGroundCropResidueIncorporated",
+                            "belowGroundCropResidue",
+                            "discardedCropLeftOnField",
+                            "discardedCropIncorporated"
+                        ],
+                        "value": "",
+                        "properties": [
+                            {
+                                "@type": "Property",
+                                "term.@id": "carbonContent",
+                                "value": ""
+                            },
+                            {
+                                "@type": "Property",
+                                "term.@id": "nitrogenContent",
+                                "value": ""
+                            },
+                            {
+                                "@type": "Property",
+                                "term.@id": "ligninContent",
+                                "value": ""
+                            }
+                        ]
+                    }
+                ],
+                "inputs": [
+                    {
+                        "@type": "Input",
+                        "term.termType": ["organicFertiliser", "soilAmendment"],
+                        "value": "",
+                        "properties": [
+                            {
+                                "@type": "Property",
+                                "term.@id": "carbonContent",
+                                "value": ""
+                            },
+                            {
+                                "@type": "Property",
+                                "term.@id": "nitrogenContent",
+                                "value": ""
+                            },
+                            {
+                                "@type": "Property",
+                                "term.@id": "ligninContent",
+                                "value": ""
+                            }
+                        ]
+                    }
+                ],
+                "practices": [
+                    {
+                        "@type": "Practice",
+                        "term.termType": "tillage",
+                        "value": ""
+                    },
+                    {
+                        "@type": "Practice",
+                        "term.termType": "waterRegime",
+                        "name": "irrigated",
+                        "value": "",
+                        "startDate": "",
+                        "endDate": ""
+                    }
+                ],
+                "optional": {
+                    "startDate": ""
+                }
+            }]
+        }
+    }
+}
+LOOKUPS = {
     "crop": "IPCC_LAND_USE_CATEGORY",
     "landCover": "IPCC_LAND_USE_CATEGORY",
     "tillage": "IPCC_TILLAGE_MANAGEMENT_CATEGORY"
 }
+RETURNS = {
+    "Measurement": [{
+        "value": "",
+        "sd": "",
+        "min": "",
+        "max": "",
+        "statsDefinition": "simulated",
+        "observations": "",
+        "dates": "",
+        "depthUpper": "0",
+        "depthLower": "30",
+        "methodClassification": "tier 2 model"
+    }]
+}
 
 TERM_ID = 'organicCarbonPerHa'
 _METHOD_CLASSIFICATION = MeasurementMethodClassification.TIER_2_MODEL.value
@@ -78,11 +203,19 @@ _CARBON_INPUT_PROPERTY_TERM_IDS = [
     _DRY_MATTER_TERM_ID
 ]
 
-_CARBON_SOURCE_TERM_TYPES = [
+_INPUT_CARBON_SOURCE_TERM_TYPES = [
     TermTermType.ORGANICFERTILISER.value,
     TermTermType.SOILAMENDMENT.value
 ]
 
+_PRACTICE_CARBON_SOURCE_TERM_TYPES = [
+    TermTermType.LANDCOVER
+]
+
+_PRODUCT_CARBON_SOURCE_TERM_TYPES = [
+    TermTermType.CROPRESIDUE
+]
+
 _VALID_SITE_TYPES = [
     SiteSiteType.CROPLAND.value
 ]
@@ -124,7 +257,7 @@ def _measurement(
     dict
         A valid HESTIA `Measurement` node, see: https://www.hestia.earth/schema/Measurement.
     """
-    measurement = _new_measurement(TERM_ID) | descriptive_stats_dict
+    measurement = _new_measurement(TERM_ID, MODEL) | descriptive_stats_dict
     measurement["dates"] = [f"{year}-12-31" for year in timestamps]
     measurement["depthUpper"] = DEPTH_UPPER
     measurement["depthLower"] = DEPTH_LOWER
@@ -1173,7 +1306,7 @@ def _compile_inventory(
     TODO: implement long-term average climate data and annual climate data as back ups for monthly data
     TODO: implement randomisation for `irrigationMonthly` if `startDate` and `endDate` are not provided
     """
-    grouped_cycles = group_nodes_by_year(cycles)
+    grouped_cycles = group_nodes_by_year(cycles, include_spillovers=True)
     grouped_measurements = group_nodes_by_year(measurement_nodes, mode=GroupNodesByYearMode.DATES)
 
     grouped_climate_data = _get_grouped_climate_measurements(grouped_measurements)
@@ -1321,12 +1454,29 @@ def _get_carbon_sources(cycle: dict) -> list[CarbonSource]:
     list[CarbonSource]
         A formatted list of `CarbonSource`s.
     """
-    inputs_and_products = cycle.get("inputs", []) + cycle.get("products", [])
+    carbon_source_nodes = filter_list_term_type(
+        cycle.get("inputs", []) + cycle.get("practices", []) + cycle.get("products", []),
+        _INPUT_CARBON_SOURCE_TERM_TYPES + _PRACTICE_CARBON_SOURCE_TERM_TYPES + _PRODUCT_CARBON_SOURCE_TERM_TYPES
+    )
+
+    group_fac = cycle.get('fraction_of_group_duration')
+    node_fac = cycle.get('fraction_of_node_duration')
+
+    scaling_fac = group_fac if round(group_fac * 100) >= round(node_fac * 100) else 1
+
+    kwargs = {
+        "cycle": cycle,
+        "scaling_factor": scaling_fac
+    }
+
     return non_empty_list([
         next(
-            (_func(node, cycle) for validator, _func in _CARBON_SOURCE_DECISION_TREE.items() if validator(node)),
+            (
+                _func(node, **kwargs) for validator, _func in _CARBON_SOURCE_DECISION_TREE.items()
+                if validator(node)
+            ),
             None
-        ) for node in inputs_and_products
+        ) for node in carbon_source_nodes
     ])
 
 
@@ -1348,7 +1498,9 @@ def _should_run_carbon_source_ag_residue(node: dict) -> bool:
     return node.get("term", {}).get("@id") == _ABOVE_GROUND_CROP_RESIDUE_TOTAL_TERM_ID
 
 
-def _calc_carbon_source_ag_crop_residue(node: dict, cycle: dict) -> Union[CarbonSource, None]:
+def _calc_carbon_source_ag_crop_residue(
+    node: dict, *, cycle: dict, scaling_factor: float, **_
+) -> Union[CarbonSource, None]:
     """
     Extract and format the carbon source data for above-ground crop residues.
 
@@ -1360,6 +1512,11 @@ def _calc_carbon_source_ag_crop_residue(node: dict, cycle: dict) -> Union[Carbon
     ----------
     node : dict
         A HESTIA [Product](https://www.hestia.earth/schema/Product) node with `term.termType` == `landCover`.
+    cycle : dict
+        The HESTIA [Cycle](https://www.hestia.earth/schema/Cycle) that produces the crop residue.
+    scaling_factor : float
+        The scaling factor for the mass of carbon input, calculated by estimating how much the cycle overlaps
+        with the current inventory year.
 
     Returns
     -------
@@ -1371,7 +1528,7 @@ def _calc_carbon_source_ag_crop_residue(node: dict, cycle: dict) -> Union[Carbon
         get_node_value(practice) for practice in cycle.get("practices", [])
         if node_term_match(practice, _CROP_RESIDUE_MANAGEMENT_TERM_IDS)
     ])
-    mass = value * max(residue_left_on_field, _MIN_RESIDUE_LEFT_ON_FIELD) / 100
+    mass = value * max(residue_left_on_field, _MIN_RESIDUE_LEFT_ON_FIELD) * scaling_factor / 100
 
     carbon_content, nitrogen_content, lignin_content, dry_matter = _retrieve_carbon_source_properties(node)
 
@@ -1400,7 +1557,7 @@ def _should_run_carbon_source_cover_crop(node: dict) -> bool:
     bool
         Whether the node satisfies the critera.
     """
-    LOOKUP = _LOOKUPS["landCover"]
+    LOOKUP = LOOKUPS["landCover"]
     TARGET_LOOKUP_VALUES = IPCC_LAND_USE_CATEGORY_TO_LAND_COVER_LOOKUP_VALUE[IpccLandUseCategory.ANNUAL_CROPS]
 
     return (
@@ -1410,7 +1567,7 @@ def _should_run_carbon_source_cover_crop(node: dict) -> bool:
     )
 
 
-def _calc_carbon_source_cover_crop(node: dict, *_) -> Union[CarbonSource, None]:
+def _calc_carbon_source_cover_crop(node: dict, *, scaling_factor: float, **_) -> Union[CarbonSource, None]:
     """
     Extract and format the carbon source data for an annual cover crop.
 
@@ -1420,6 +1577,9 @@ def _calc_carbon_source_cover_crop(node: dict, *_) -> Union[CarbonSource, None]:
     ----------
     node : dict
         A HESTIA [Product](https://www.hestia.earth/schema/Product) node with `term.termType` == `landCover`.
+    scaling_factor : float
+        The scaling factor for the mass of carbon input, calculated by estimating how much the cycle overlaps
+        with the current inventory year.
 
     Returns
     -------
@@ -1428,7 +1588,7 @@ def _calc_carbon_source_cover_crop(node: dict, *_) -> Union[CarbonSource, None]:
     """
     value = get_node_value(node)
     carbon_source = CarbonSource(
-        _DEFAULT_COVER_CROP_BIOMASS * value / 100,
+        _DEFAULT_COVER_CROP_BIOMASS * value * scaling_factor / 100,
         _Parameter.DEFAULT_CARBON_CONTENT.value.get("value"),
         _Parameter.DEFAULT_NITROGEN_CONTENT.value.get("value"),
         _Parameter.DEFAULT_NITROGEN_CONTENT.value.get("value")
@@ -1453,11 +1613,11 @@ def _should_run_carbon_source(node: dict) -> bool:
     """
     return any([
         node.get("term", {}).get("@id") in _CARBON_SOURCE_TERM_IDS,
-        node.get("term", {}).get("termType") in _CARBON_SOURCE_TERM_TYPES
+        node.get("term", {}).get("termType") in _INPUT_CARBON_SOURCE_TERM_TYPES
     ])
 
 
-def _calc_carbon_source(node: dict, *_) -> Union[CarbonSource, None]:
+def _calc_carbon_source(node: dict, *, scaling_factor: float, **_) -> Union[CarbonSource, None]:
     """
     Extract and format the carbon source data for an input or product.
 
@@ -1466,13 +1626,17 @@ def _calc_carbon_source(node: dict, *_) -> Union[CarbonSource, None]:
     node : dict
         A HESTIA [Input](https://www.hestia.earth/schema/Input) or [Product](https://www.hestia.earth/schema/Product)
         node.
+    scaling_factor : float
+        The scaling factor for the mass of carbon input, calculated by estimating how much the cycle overlaps
+        with the current inventory year.
+
 
     Returns
     -------
     CarbonSource | None
         The carbon source data of the cover crop, or `None` if carbon source data incomplete.
     """
-    mass = get_node_value(node)
+    mass = get_node_value(node) * scaling_factor
     carbon_content, nitrogen_content, lignin_content, dry_matter = _retrieve_carbon_source_properties(node)
 
     carbon_source = CarbonSource(
@@ -1673,7 +1837,7 @@ def _check_cycle_tillage_management_category(
     bool
         Whether or not the cycle meets the requirements for the category.
     """
-    LOOKUP = _LOOKUPS["tillage"]
+    LOOKUP = LOOKUPS["tillage"]
     target_lookup_values = IPCC_MANAGEMENT_CATEGORY_TO_TILLAGE_MANAGEMENT_LOOKUP_VALUE.get(key, None)
 
     practices = cycle.get("practices", [])
@@ -1720,7 +1884,7 @@ def _get_grouped_is_paddy_rice(grouped_cycles: dict) -> dict:
 
 
 def _check_is_paddy_rice(cycles: list[dict]) -> bool:
-    LOOKUP = _LOOKUPS["crop"]
+    LOOKUP = LOOKUPS["crop"]
     TARGET_LOOKUP_VALUES = IPCC_LAND_USE_CATEGORY_TO_LAND_COVER_LOOKUP_VALUE.get(
         IpccLandUseCategory.PADDY_RICE_CULTIVATION, None
     )
