@@ -30,7 +30,10 @@ REQUIREMENTS = {
 }
 RETURNS = {
     "Indicator": [{
-        "value": ""
+        "value": "",
+        "inputs": "",
+        "landCover": "",
+        "previousLandCover": ""
     }]
 }
 TERM_ID = 'landTransformation100YearAverageInputsProduction'
