@@ -52,7 +52,7 @@ REQUIREMENTS = {
             }
         ],
         "optional": {
-            "practices": [{"@type": "Practice", "term.termType": "systemn"}]
+            "practices": [{"@type": "Practice", "term.termType": "system"}]
         }
     }
 }
@@ -129,7 +129,9 @@ def _should_run(cycle: dict):
             logRequirements(cycle, model=MODEL, term=term_id, model_key=MODEL_KEY,
                             is_liveAquaticSpecies=is_liveAquaticSpecies,
                             product_value=product_value,
-                            nitrogen_content=nitrogen_content)
+                            nitrogen_content=nitrogen_content,
+                            inputs_n=inputs_n,
+                            products_n=products_n)
 
         else:
             logRequirements(cycle, model=MODEL, term=term_id, model_key=MODEL_KEY,
