@@ -29,7 +29,7 @@ def _practice(value: float):
 
 def _get_value(product: dict):
     term_id = product.get('term', {}).get('@id', '')
-    return safe_parse_float(get_crop_lookup_value(MODEL, TERM_ID, term_id, LOOKUPS['crop']), None)
+    return safe_parse_float(get_crop_lookup_value(MODEL, TERM_ID, term_id, LOOKUPS['crop']), default=None)
 
 
 def run(cycle: dict):
