@@ -1,10 +1,3 @@
-"""
-Default Method Classification.
-
-When gap-filling `management` node on Site, the
-`defaultMethodClassification` and `defaultMethodClassificationDescription` fields become required.
-This model will use the first value in the `management` node.
-"""
 from hestia_earth.schema import SiteDefaultMethodClassification
 
 from hestia_earth.models.log import logRequirements, logShouldRun
