@@ -28,7 +28,7 @@ RETURNS = {
             "@type": "Input",
             "term.termType": "excreta",
             "value": "",
-            "fromCycle": "true"
+            "fromCycle": "True"
         }]
     }]
 }
