@@ -22,11 +22,11 @@ from hestia_earth.utils.tools import (
     list_sum,
     list_average,
     safe_parse_date,
-    safe_parse_float,
     non_empty_list
 )
 from hestia_earth.utils.lookup_utils import (
     is_model_siteType_allowed,
+    is_model_product_id_allowed,
     is_siteType_allowed,
     is_product_id_allowed,
     is_product_termType_allowed,
@@ -113,7 +113,10 @@ def properties_logs(blank_nodes: list, properties: Union[dict, list]):
 
 def group_by_keys(group_keys: list = ['term']):
     def run(group: dict, node: dict):
-        group_key = '-'.join(non_empty_list(map(lambda v: node.get(v, {}).get('@id'), group_keys)))
+        group_key = '-'.join(non_empty_list([
+            node.get(v, {}).get('@id') if isinstance(node.get(v), dict) else node.get(v)
+            for v in group_keys
+        ]))
         group[group_key] = group.get(group_key, []) + [node]
         return group
     return run
@@ -124,13 +127,16 @@ def _module_term_id(term_id: str, module):
     return getattr(module, 'TERM_ID', term_id_str).split(',')[0]
 
 
-def _run_model_required(model: str, term_id: str, data: dict):
+def _run_model_required(model: str, term_id: str, data: dict, skip_logs: bool = False):
     siteType_allowed = is_model_siteType_allowed(model, term_id, data)
+    product_id_allowed = is_model_product_id_allowed(model, term_id, data)
 
-    run_required = all([siteType_allowed])
-    debugValues(data, model=model, term=term_id,
-                run_required=run_required,
-                siteType_allowed=siteType_allowed)
+    run_required = all([siteType_allowed, product_id_allowed])
+    if not skip_logs:
+        debugValues(data, model=model, term=term_id,
+                    run_required=run_required,
+                    siteType_allowed=siteType_allowed,
+                    product_id_allowed=product_id_allowed)
     return run_required
 
 
@@ -153,7 +159,7 @@ def _run_required(model: str, term_id: str, data: dict):
                     input_id_allowed=input_id_allowed,
                     input_termType_allowed=input_termType_allowed)
         # logging this for the model would cause issues parsing statuses
-        if model != 'emissionNotRelevant':
+        if not model.endswith('NotRelevant'):
             debugValues(data, model=model, term=term_id, run_required=run_required)
     return run_required
 
@@ -234,16 +240,21 @@ def get_total_value(nodes: list):
 
 def _value_as(term_id: str, convert_to_property=True):
     def get_value(node: dict):
-        property = get_node_property(node, term_id)
+        factor = get_node_property_value(
+            None, node, term_id, default=0, handle_percents=False
+        ) or get_lookup_value(
+            lookup_term=node.get('term', {}),
+            column=term_id
+        ) or 0
         # ignore node value if property is not found
-        factor = safe_parse_float(property.get('value', 0))
         value = list_sum(node.get('value', []))
+        property = get_node_property(node, term_id, find_default_property=False, download_from_hestia=True)
         ratio = factor / 100 if property.get('term', {}).get('units', '') == '%' else factor
         return 0 if ratio == 0 else (value * ratio if convert_to_property else value / ratio)
     return get_value
 
 
-def get_total_value_converted(nodes: list, conversion_property, convert_to_property=True):
+def get_total_value_converted(nodes: list, conversion_property: Union[List[str], str], convert_to_property=True):
     """
     Get the total `value` of a list of Blank Nodes converted using a property of each Blank Node.
 
@@ -367,14 +378,39 @@ def get_KG_total(nodes: list) -> list:
     return get_total_value(kg_nodes) + get_total_value_converted(kg_N_nodes, 'nitrogenContent', False)
 
 
+def get_P_total(nodes: list) -> list:
+    """
+    Get the total phosphorous content of a list of Blank Node.
+
+    The result contains the values of the following nodes:
+    1. Every blank node specified in `kg P` will be used.
+    1. Every blank node specified in `kg N` will be multiplied by the `phosphateContentAsP` property.
+    2. Every blank node specified in `kg` will be multiplied by the `phosphateContentAsP` property.
+
+    Parameters
+    ----------
+    nodes : list
+        A list of Blank Node.
+
+    Returns
+    -------
+    list
+        The phosphorous values as a list of numbers.
+    """
+    kg_P_nodes = _filter_list_term_unit(nodes, Units.KG_P)
+    kg_N_nodes = _filter_list_term_unit(nodes, Units.KG_N)
+    kg_nodes = _filter_list_term_unit(nodes, Units.KG)
+    return get_total_value(kg_P_nodes) + get_total_value_converted(kg_N_nodes + kg_nodes, 'phosphateContentAsP')
+
+
 def get_P2O5_total(nodes: list) -> list:
     """
     Get the total phosphate content of a list of Blank Node.
 
     The result contains the values of the following nodes:
-    1. Every organic fertiliser specified in `kg P2O5` will be used.
-    1. Every organic fertiliser specified in `kg N` will be multiplied by the `phosphateContentAsP2O5` property.
-    2. Every organic fertiliser specified in `kg` will be multiplied by the `phosphateContentAsP2O5` property.
+    1. Every blank node specified in `kg P2O5` will be used.
+    1. Every blank node specified in `kg N` will be multiplied by the `phosphateContentAsP2O5` property.
+    2. Every blank node specified in `kg` will be multiplied by the `phosphateContentAsP2O5` property.
 
     Parameters
     ----------
@@ -386,10 +422,10 @@ def get_P2O5_total(nodes: list) -> list:
     list
         The phosphate values as a list of numbers.
     """
-    kg_P_nodes = _filter_list_term_unit(nodes, Units.KG_P2O5)
+    kg_P2O5_nodes = _filter_list_term_unit(nodes, Units.KG_P2O5)
     kg_N_nodes = _filter_list_term_unit(nodes, Units.KG_N)
     kg_nodes = _filter_list_term_unit(nodes, Units.KG)
-    return get_total_value(kg_P_nodes) + get_total_value_converted(kg_N_nodes + kg_nodes, 'phosphateContentAsP2O5')
+    return get_total_value(kg_P2O5_nodes) + get_total_value_converted(kg_N_nodes + kg_nodes, 'phosphateContentAsP2O5')
 
 
 def convert_to_nitrogen(node: dict, model: str, blank_nodes: list, **log_args):
@@ -398,9 +434,17 @@ def convert_to_nitrogen(node: dict, model: str, blank_nodes: list, **log_args):
         return value or get_node_property_value(model, input, 'crudeProteinContent', default=0, **log_args) / 6.25
 
     values = [(i, prop_value(i)) for i in blank_nodes]
-    missing_nitrogen_property = [i.get('term', {}).get('@id') for i, p_value in values if not p_value]
+    missing_nitrogen_property = [i.get('term', {}).get('@id') for i, value in values if not value]
 
     debugValues(node, model=model,
+                conversion_details=log_as_table([
+                    {
+                        'id': i.get('term', {}).get('@id'),
+                        'value': list_sum(i.get('value', [])),
+                        'nitrogenContent': value
+                    }
+                    for i, value in values
+                ]),
                 missing_nitrogen_property=';'.join(set(missing_nitrogen_property)),
                 **log_args)
 
@@ -1010,6 +1054,7 @@ def group_nodes_by_year(
     nodes: list[dict],
     default_node_duration: int = 1,
     sort_result: bool = True,
+    include_spillovers: bool = False,
     inner_key: Union[Any, None] = None,
     mode: GroupNodesByYearMode = GroupNodesByYearMode.START_AND_END_DATE
 ) -> dict[int, list[dict]]:
@@ -1026,6 +1071,10 @@ def group_nodes_by_year(
         Default duration of a node years if start date is not available, by default 1.
     sort_result : bool, optional
         Flag to sort the result by year, by default True.
+    include_spillovers : bool, optional
+        If grouping by start and end date, flag to determine whether nodes should be included in year groups that they
+        spill-over into. If `False` year groups will not include nodes that overlap with them by less than 30% of a
+        year, unless it is the only year group it overlaps with. By default False.
     inner_key: Any | None
         An optional inner dictionary key for the outputted annualised groups (can be used to merge annualised
         dictionaries together), default value: `None`.
@@ -1066,6 +1115,7 @@ def group_nodes_by_year(
 
             should_run = (
                 mode == GroupNodesByYearMode.DATES
+                or include_spillovers
                 or _validate_time_fraction_dict(
                     time_fraction_dict,
                     is_final_year
@@ -1276,16 +1326,18 @@ def get_inputs_from_properties(input: dict, term_types: Union[TermTermType, List
     dict
         A dictionary of nodes grouped by latest date, in the format `{date: list[node]}`.
     """
+    term = input.get('term', {})
     input_value = list_sum(input.get('value', []))
     properties = (
         input.get('properties') or
-        input.get('term', {}).get('defaultProperties') or
-        download_term(input.get('term', {})).get('defaultProperties')
+        term.get('defaultProperties') or
+        download_term(term).get('defaultProperties')
     )
     inputs = non_empty_list([
         {
             'term': p.get('key'),
-            'value': [(p.get('value') / 100) * (p.get('share', 100) / 100) * input_value]
+            'value': [(p.get('value') / 100) * (p.get('share', 100) / 100) * input_value],
+            'parent': term
         } for p in (properties or []) if all([p.get('key'), p.get('value')])
     ]) if input_value > 0 else []
     return filter_list_term_type(inputs, term_types)
