@@ -1,10 +1,10 @@
 from typing import Optional
 from hestia_earth.schema import TermTermType
-from hestia_earth.utils.model import find_term_match, filter_list_term_type
+from hestia_earth.utils.model import filter_list_term_type
 from hestia_earth.utils.tools import list_sum, safe_parse_date
 
-from hestia_earth.models.log import debugValues, log_as_table
-from .lookup import all_factor_value, _term_factor_value, _aware_factor_value, fallback_country
+from hestia_earth.models.log import debugValues
+from .lookup import all_factor_value, _region_factor_value, _aware_factor_value, fallback_country
 from .product import find_by_product
 from .site import region_level_1_id
 
@@ -50,7 +50,7 @@ def get_site(impact_assessment: dict) -> dict:
     return impact_assessment.get('site') or impact_assessment.get('cycle', {}).get('site') or {}
 
 
-def get_region_id(impact_assessment: dict) -> str:
+def get_region_id(impact_assessment: dict, blank_node: dict = None) -> str:
     """
     Get the country or region @id of the ImpactAssessment.
     Note: level 1 GADM region will be returned only, even if the region is of level > 1.
@@ -59,18 +59,29 @@ def get_region_id(impact_assessment: dict) -> str:
     ----------
     impact_assessment : dict
         The `ImpactAssessment`.
+    blank_node : dict
+        If getting a value for a specific `emissionsResourceUse`, will try to get country from it.
 
     Returns
     -------
     str
         The `@id` of the `region`.
     """
-    site = get_site(impact_assessment)
-    term_id = site.get('region', site.get('country', impact_assessment.get('country', {}))).get('@id')
-    return term_id if not term_id.startswith('GADM') else region_level_1_id(term_id)
+    term_id: str = (
+        (blank_node or {}).get('region') or
+        (blank_node or {}).get('country') or
+        impact_assessment.get('country') or
+        get_site(impact_assessment).get('region') or
+        get_site(impact_assessment).get('country') or
+        {}
+    ).get('@id')
+    return (
+        term_id if not term_id.startswith('GADM-') else
+        region_level_1_id(term_id)
+    ) if term_id else None
 
 
-def get_country_id(impact_assessment: dict) -> str:
+def get_country_id(impact_assessment: dict, blank_node: dict = None) -> str:
     """
     Get the country or @id of the ImpactAssessment.
 
@@ -78,13 +89,21 @@ def get_country_id(impact_assessment: dict) -> str:
     ----------
     impact_assessment : dict
         The `ImpactAssessment`.
+    blank_node : dict
+        If getting a value for a specific `emissionsResourceUse`, will try to get country from it.
 
     Returns
     -------
     str
         The `@id` of the `country`.
     """
-    return impact_assessment.get('country', get_site(impact_assessment).get('country', {})).get('@id')
+    term_id = (
+        (blank_node or {}).get('country') or
+        impact_assessment.get('country') or
+        get_site(impact_assessment).get('country') or
+        {}
+    ).get('@id')
+    return term_id if term_id else None
 
 
 def impact_emission_lookup_value(
@@ -112,8 +131,8 @@ def impact_emission_lookup_value(
         The impact total value.
     """
     return all_factor_value(
-        model=model,
-        term_id=term_id,
+        logs_model=model,
+        logs_term_id=term_id,
         node=impact,
         lookup_name='emission.csv',
         lookup_col=lookup_col,
@@ -124,8 +143,8 @@ def impact_emission_lookup_value(
 
 
 def impact_country_value(
-    model: str,
-    term_id: str,
+    logs_model: str,
+    logs_term_id: str,
     impact: dict,
     lookup: str,
     group_key: str = None,
@@ -137,9 +156,9 @@ def impact_country_value(
 
     Parameters
     ----------
-    model : str
+    logs_model : str
         The model to display in the logs only.
-    term_id : str
+    logs_term_id : str
         The term to display in the logs only.
     impact : dict
         The `ImpactAssessment`.
@@ -157,22 +176,22 @@ def impact_country_value(
         The impact total value.
     """
     term_type = TermTermType.RESOURCEUSE.value if 'resourceUse' in lookup else TermTermType.EMISSION.value
-    nodes = filter_list_term_type(impact.get('emissionsResourceUse', []), term_type)
+    blank_nodes = filter_list_term_type(impact.get('emissionsResourceUse', []), term_type)
 
     country_id = get_country_id(impact)
     country_id = fallback_country(country_id, [lookup]) if country_fallback else country_id
 
-    values = list(map(_term_factor_value(model, term_id, lookup, country_id, group_key), nodes))
-    debugValues(impact, model=model, term=term_id,
-                values_used=log_as_table(values))
-
-    has_values = len(values) > 0
-    missing_values = set([v.get('id') for v in values if v.get('value') and v.get('coefficient') is None])
-    all_with_factors = not missing_values
-    values = [float((v.get('value') or 0) * (v.get('coefficient') or 0)) for v in values]
-
-    # fail if some factors are missing
-    return None if not all_with_factors else (list_sum(values) if has_values else default_no_values)
+    return all_factor_value(
+        logs_model=logs_model,
+        logs_term_id=logs_term_id,
+        node=impact,
+        lookup_name=lookup,
+        lookup_col=country_id,
+        blank_nodes=blank_nodes,
+        grouped_key=group_key,
+        default_no_values=default_no_values,
+        factor_value_func=_region_factor_value
+    )
 
 
 def impact_aware_value(model: str, term_id: str, impact: dict, lookup: str, group_key: str = None) -> float:
@@ -197,14 +216,23 @@ def impact_aware_value(model: str, term_id: str, impact: dict, lookup: str, grou
     int
         The impact total value.
     """
-    nodes = impact.get('emissionsResourceUse', [])
+    blank_nodes = impact.get('emissionsResourceUse', [])
     site = get_site(impact)
     aware_id = site.get('awareWaterBasinId')
     if aware_id is None:
         return None
-    factors = list(map(_aware_factor_value(model, term_id, lookup, aware_id, group_key), nodes))
-    values = [value for value in factors if value is not None]
-    return list_sum(values) if len(values) > 0 else None
+
+    return all_factor_value(
+        logs_model=model,
+        logs_term_id=term_id,
+        node=impact,
+        lookup_name=lookup,
+        lookup_col=aware_id,
+        blank_nodes=blank_nodes,
+        grouped_key=group_key,
+        default_no_values=None,
+        factor_value_func=_aware_factor_value
+    )
 
 
 def impact_endpoint_value(model: str, term_id: str, impact: dict, lookup_col: str) -> float:
@@ -232,8 +260,8 @@ def impact_endpoint_value(model: str, term_id: str, impact: dict, lookup_col: st
         not i.get('methodModel').get('@id').startswith(model[0:6])  # allow other non-related models to be accounted for
     )]
     return all_factor_value(
-        model=model,
-        term_id=term_id,
+        logs_model=model,
+        logs_term_id=term_id,
         node=impact,
         lookup_name='characterisedIndicator.csv',
         lookup_col=lookup_col,
@@ -242,10 +270,6 @@ def impact_endpoint_value(model: str, term_id: str, impact: dict, lookup_col: st
     )
 
 
-def emission_value(impact_assessment: dict, term_id: str):
-    return find_term_match(impact_assessment.get('emissionsResourceUse', []), term_id).get('value')
-
-
 def convert_value_from_cycle(
     log_node: dict, product: dict, value: float, default=None, model: str = None, term_id: str = None
 ):
