@@ -17,5 +17,5 @@ PRODUCTIVITY_KEY = {
 
 
 def get_productivity(country: dict, default: PRODUCTIVITY = PRODUCTIVITY.HIGH):
-    hdi = safe_parse_float(get_lookup_value(country, 'hdi'), None)
+    hdi = safe_parse_float(get_lookup_value(country, 'hdi'), default=None)
     return next((key for key in PRODUCTIVITY_KEY if hdi and PRODUCTIVITY_KEY[key](hdi)), default)
