@@ -1,7 +1,6 @@
 import json
-from unittest.mock import patch, Mock
-
 from pytest import mark
+from unittest.mock import patch, Mock
 
 from hestia_earth.models.environmentalFootprintV3_1 import MODEL_FOLDER
 from hestia_earth.models.environmentalFootprintV3_1.environmentalFootprintSingleOverallScore import MODEL, TERM_ID, \
@@ -20,6 +19,7 @@ def fake_rounded_indicator(value: float):
 
 methodModelEFV31 = {"@type": "Term", "@id": "environmentalFootprintV3-1"}
 methodModelFantkeEtAl2016 = {"@type": "Term", "@id": "fantkeEtAl2016"}
+methodModelfrischknechtEtAl2000 = {"@type": "Term", "@id": "frischknechtEtAl2000"}
 
 ozone_indicator = {"@type": "Indicator",
                    "term": {"@id": "ozoneDepletionPotential", "termType": "characterisedIndicator"},
@@ -68,6 +68,22 @@ bad_indicator_no_method_model = {
     "value": 0.000420443840380047
 }
 
+ionising_radiation_indicator_radon = {
+    "@type": "Indicator",
+    "term": {"@id": "ionisingRadiationKbqU235Eq", "termType": "characterisedIndicator"},
+    "value": 0.11156637927360424,
+    "inputs": [{"@id": "radon222"}],
+    "methodModel": methodModelfrischknechtEtAl2000
+}
+
+ionising_radiation_indicator_plutonium238 = {
+    "@type": "Indicator",
+    "term": {"@id": "ionisingRadiationKbqU235Eq", "termType": "characterisedIndicator"},
+    "value": 8.567909489437642e-13,
+    "inputs": [{"@id": "plutonium238"}],
+    "methodModel": methodModelfrischknechtEtAl2000
+}
+
 
 @mark.parametrize(
     "impacts, expected, num_inputs",
@@ -84,6 +100,8 @@ bad_indicator_no_method_model = {
         ([ozone_indicator, acid_indicator], True, 2),
         ([ozone_indicator, other_valid_ozone_indicator], True, 1),
         ([bad_indicator_no_val, acid_indicator], False, 1),
+        ([ionising_radiation_indicator_radon, ionising_radiation_indicator_plutonium238], True, 2),
+        ([ionising_radiation_indicator_radon, ionising_radiation_indicator_radon], False, 2),
     ],
     ids=[
         "No indicators => no run",
@@ -98,6 +116,8 @@ bad_indicator_no_method_model = {
         "2 good indicators => run",
         "2 ozone_indicator different methodModel => run with 1",
         "one bad one good indicator => no run",
+        "multiple radiation indicators => run with 2",
+        "duplicate radiation indicators => no run",
     ]
 )
 def test_should_run(impacts, expected, num_inputs):
