@@ -1,18 +1,19 @@
-import csv
+import os
 import json
-import numpy as np
 import pytest
 from unittest.mock import patch
 
 from tests.utils import fixtures_path, fake_new_management
 from hestia_earth.models.faostat2018.utils import MODEL as FAOSTAT_MODEL
 from hestia_earth.models.hestia.landCover import (
-    MODEL, MODEL_KEY, get_changes, _estimate_maximum_forest_change,
-    run, site_area_sum_to_100, _get_sums_of_crop_expansion, _get_sum_for_land_category, scale_values_to_one
+    MODEL, MODEL_KEY, _get_changes, _estimate_maximum_forest_change,
+    run, site_area_sum_to_100, _get_sums_of_crop_expansion, _get_sum_for_land_category, scale_values_to_one,
+    _get_most_common_or_alphabetically_first
 )
 
 CLASS_PATH = f"hestia_earth.models.{MODEL}.{MODEL_KEY}"
 fixtures_folder = f"{fixtures_path}/{MODEL}/{MODEL_KEY}"
+_folders = [d for d in os.listdir(fixtures_folder) if os.path.isdir(os.path.join(fixtures_folder, d))]
 
 FAOSTAT_CLASS_PATH = f"hestia_earth.models.{FAOSTAT_MODEL}.utils"
 faostat_fixtures_folder = f"{fixtures_path}/{FAOSTAT_MODEL}/utils"
@@ -42,21 +43,30 @@ BRAZIL_SITE = {
 }
 
 
-def recfromcsv_mod(filename, **kwargs):
-    def rewrite_csv_as_tab(csv_name):
-        with open(csv_name, newline='') as fp:
-            for row in csv.reader(fp, delimiter=","):
-                yield "\t".join(row)
-    return np.recfromcsv(
-        rewrite_csv_as_tab(filename), delimiter="\t", encoding=None, **kwargs)
-
-
-def _download_fixture(filepath: str):
-    return recfromcsv_mod(filename=filepath)
+@pytest.mark.parametrize(
+    "terms,expected_output",
+    [
+        (   # Only term
+            ["Annual crops", "Annual crops"],
+            "Annual crops"
+        ),
+        (  # Most common
+            ["Perennial crops", "Perennial crops", "Annual crops"],
+            "Perennial crops"
+        ),
+        (   # Tied frequency, Alphabetically first
+            ["Perennial crops", "Perennial crops", "Annual crops", "Annual crops"],
+            "Annual crops"
+        )
+    ]
+)
+def test_get_most_common_or_alphabetically_first(terms, expected_output):
+    actual_result = _get_most_common_or_alphabetically_first(terms)
+    assert actual_result == expected_output
 
 
 def test_get_changes():
-    result, missing_values = get_changes(
+    result, missing_values = _get_changes(
         country_id="GADM-AFG",
         end_year=2010
     )
@@ -232,26 +242,9 @@ def test_scale_values_to_one(dictionary, expected_result):
         assert round(v, 3) == round(expected_result[k], 3)
 
 
-@pytest.mark.parametrize(
-    "subfolder",
-    [
-        "albania_example",
-        "argentina_example",
-        "armenia_example",
-        "brazil_example",
-        "zimbabwe_example",
-        "brazil_empty_example",
-        "gbr_example",
-        "malaysia",
-        "prior_landCover",
-        "nigeria_cassava",
-        "cover_crops",
-        "missing_fao_date",
-        "iran_sistan"
-    ]
-)
+@pytest.mark.parametrize("subfolder", _folders)
 @patch(f"{CLASS_PATH}._new_management", side_effect=fake_new_management)
-def test_run(mock, subfolder):
+def test_run(mock, subfolder: str):
     folder = f"{fixtures_folder}/{subfolder}"
     with open(f"{folder}/site.jsonld", encoding='utf-8') as f:
         site = json.load(f)
