@@ -120,7 +120,8 @@ SOIL_CATEGORY_PARAMS = [
     ("usdaSoilType/pod", IpccSoilCategory.SPODIC_SOILS),
     ("usdaSoilType/san", IpccSoilCategory.SANDY_SOILS),
     ("usdaSoilType/vol", IpccSoilCategory.VOLCANIC_SOILS),
-    ("usdaSoilType/wet", IpccSoilCategory.WETLAND_SOILS)
+    ("usdaSoilType/wet", IpccSoilCategory.WETLAND_SOILS),
+    ("with-depths", IpccSoilCategory.HIGH_ACTIVITY_CLAY_SOILS)  # Closes #1248
 ]
 
 
@@ -196,7 +197,12 @@ MANAGEMENT_CATEGORY_PARAMS = [
     ("high-intensity-grazing", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.HIGH_INTENSITY_GRAZING),
     ("improved-grassland", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.IMPROVED_GRASSLAND),
     ("no-tillage", IpccLandUseCategory.ANNUAL_CROPS, IpccManagementCategory.NO_TILLAGE),
-    ("nominally-managed", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.NOMINALLY_MANAGED),
+    ("nominally-managed/native-pasture", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.NOMINALLY_MANAGED),
+    (
+        "nominally-managed/nominally-managed-pasture",
+        IpccLandUseCategory.GRASSLAND,
+        IpccManagementCategory.NOMINALLY_MANAGED
+    ),
     ("not-relevant", IpccLandUseCategory.OTHER, IpccManagementCategory.NOT_RELEVANT),
     ("reduced-tillage", IpccLandUseCategory.ANNUAL_CROPS, IpccManagementCategory.REDUCED_TILLAGE),
     ("severely-degraded", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.SEVERELY_DEGRADED),
